@@ -1,6 +1,6 @@
-/* -*- Mode: C; c-file-style: "bsd" -*- */
-/* filters.h - Filter structs
- *        Copyright (C) 2002 Timo Schulz
+/* -*- Mode: C; c-file-style: "bsd" -*-
+ * filters.h - Filter structs
+ *        Copyright (C) 2002, 2003 Timo Schulz
  *
  * This file is part of OpenCDK.
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with OpenCDK; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #ifndef CDK_FILTERS_H
@@ -29,55 +29,54 @@ enum {
 };
 
 typedef struct {
-    GCRY_CIPHER_HD hd;
-    GCRY_MD_HD mdc;
+    cdk_cipher_hd_t hd;
+    cdk_md_hd_t mdc;
     int mdc_method;
-    CDK_DEK dek;
-    unsigned long datalen;
+    cdk_dek_t dek;
+    u32 datalen;
     struct {
         int on;
         size_t size;
     } blkmode;
-    CDK_STREAM s;
-} cipher_filter_s;
+    cdk_stream_t s;
+} cipher_filter_t;
 
 typedef struct {
     int digest_algo;
-    GCRY_MD_HD md;
-} md_filter_s;
+    cdk_md_hd_t md;
+} md_filter_t;
 
 typedef struct {
     const char * le; /* line endings */
     const char * hdrlines;
-    unsigned long crc;
+    u32 crc;
     int crc_okay;
-    int idx;
-    int idx2;
-} armor_filter_s;
+    int idx, idx2;
+} armor_filter_t;
 
 typedef struct {
     int mode;
     unsigned rfc1991:1;
     char * filename;
-    GCRY_MD_HD md;
+    cdk_md_hd_t md;
     struct {
         int on;
         size_t size;
     } blkmode;
-} plaintext_filter_s;
+} literal_filter_t;
 
 typedef struct {
     size_t inbufsize;
-    unsigned char inbuf[8192];
+    byte inbuf[8192];
     size_t outbufsize;
-    unsigned char outbuf[8192];
+    byte outbuf[8192];
     int algo; /* compress algo */
     int level;
-} compress_filter_s;
+} compress_filter_t;
 
 typedef struct {
     const char * lf;
-} text_filter_s;
+} text_filter_t;
 
 
 /*-- armor.c -*/
@@ -88,7 +87,7 @@ int _cdk_filter_hash( void * opaque, int ctl, FILE * in, FILE * out );
 int _cdk_filter_cipher( void * opaque, int ctl, FILE * in, FILE * out );
 
 /*-- plaintext.c --*/
-int _cdk_filter_plaintext( void * opaque, int ctl, FILE * in, FILE * out );
+int _cdk_filter_literal( void * opaque, int ctl, FILE * in, FILE * out );
 int _cdk_filter_text( void * opaque, int ctl, FILE * in, FILE * out );
 
 /*-- compress.c --*/
